CUTLASS 3.2.1 (#1113)

* Updates for 3.2.1 release.

* Minor fix in gemm op profiler for raster order.

* Add scheduler mapping for raster order in the kernels.
This commit is contained in:
ANIKET SHIVAM
2023-09-26 17:24:26 -04:00
committed by GitHub
parent e0aaa3c3b3
commit 90d3b0fb18
428 changed files with 22252 additions and 21761 deletions
+3 -44
View File
@@ -30,47 +30,6 @@
**************************************************************************************************/
#pragma once
#if !defined(__CUDACC_RTC__)
#include "cuda_runtime.h"
#include "cutlass/trace.h"
#endif
namespace cutlass {
struct KernelHardwareInfo {
//
// Data members
//
int device_id = 0;
int sm_count = 0;
//
// Methods
//
#if !defined(__CUDACC_RTC__)
static int
query_device_multiprocessor_count(int device_id = 0) {
cudaError_t result = cudaGetDevice(&device_id);
if (result != cudaSuccess) {
CUTLASS_TRACE_HOST(
" cudaGetDevice() returned error "
<< cudaGetErrorString(result));
return 0;
}
int multiprocessor_count;
result = cudaDeviceGetAttribute(&multiprocessor_count,
cudaDevAttrMultiProcessorCount, device_id);
if (result != cudaSuccess) {
CUTLASS_TRACE_HOST(
" cudaDeviceGetAttribute() returned error "
<< cudaGetErrorString(result));
return 0;
}
return multiprocessor_count;
}
#endif
};
} // namespace cutlass
// Simply import .h version of header so as to avoid breaking any existing CUTLASS builds
// after .hpp was changed to .h
#include "cutlass/kernel_hardware_info.h"